module.exports = defineTest({
	description:
		'side-effects are preserved if subject is exported in multiple ways, even if default export has no direct link to original (#733)'
});
